Python Utilities
================

This repo collects some small Python utilities that I have created (or collected) in practice,
and organizes them as a package named `zpz`.

These utilities are not "one-off" experiments; they are really useful code.
However, they do not form a coherent set of utilities for a particular application domain.
There is no plan to maintain this code as a coherent library.
This package is uploaded to [pypi](https://pypi.org/project/zpz/).
Consider it to be mainly for the author's personal convenience.
Do not assume the releases will be maintained in a stable, regular, and backward-compatible way.

One reasonable way to use it is to copy-paste whatever segments you find useful.

To install, do

```
pip install zpz
```

There are a few optional dependencies specified by 'avro' and 'lineprofiler'.
